@@ -1,6 +1,7 @@
-delete.args <-
-function(fun = NULL, args = NULL, not = NULL)
+delete.args <- function(fun = NULL, args = NULL, not = NULL, package = NULL)
 {
+  if(is.character(fun) & !is.null(package))
+    fun <- eval(parse(text = paste(package, paste(rep(":", 3), collapse = ""), fun, sep = "")))
   nf <- names(formals(fun))
   na <- names(args)
   for(elmt in na)
