@@ -1,8 +1,8 @@
-setmfrow <-
-function(np) 
+setmfrow <- function(np, ask = NULL) 
 {
   if(np > 12L) {
-    par(ask = TRUE)
+    if(is.null(ask)) ask <- TRUE
+    par(ask = ask)
     par(mfrow = c(4L, 3L))
   } else par(mfrow = n2mfrow(np))
 
